/******************************************************************************
* Kuvaus: Osinkoverotuksen erillislaskelma
******************************************************************************/


/* Makro osinkojen sarjatason laskentaan.
	vuosi:				Lainsdntvuosi
	jaktyyppi: 			Osinkoja jakaneen yhtin tyyppi:
						J noteerattu
						M noteeraamaton
						S noteeraamaton alle 500 jsenen osuuskunta
	suorlaji: 			Suorituslaji
						1 Osinko
						2 Osuuspoman korko (ennen vuotta 2015)
						3 Reit-osingot asuntojen vuokraustoiminnasta
						4 VOPR-osinko
						5 Osuuskunnan ylijm (vuodesta 2015)
						6 Osuuskunnan VOPR-ylijm (vuodesta 2015)
	netvar:				Osakeomistuksen osuus yhtin nettovarallisuudesta
	osinkoe:			Maksettu osinko/osuuspoman korko, euroa
	HenkYhtOsVapOsuus:	Listaamattoman yhtin osinkojen nettovarallisuusosuus
						verovapaille osingoille
	JulkPOOsuus:		Listattujen yhtiiden osinkojen pomaverotulon alainen osuus	
	HenkYhtOsAnsOsuus:	Listaamattomien yhtiiden nettovarallisuusrajan ylittvn
						osuuden ansiotuloveron alainen osuus
	JulkOSPOOsuus:		Julkisesti noteeratun osuuskunnan ylijmn pomatuloveron alainen osuus

*/

%macro OsinkojenJakoErillis(
		vuosi, jaktyypp, suorlaji, netvar, osinkoe,
		HenkYhtOsVapOsuus, JulkPOOsuus, HenkYhtOsAnsOsuus, JulkOSPOOsuus);

		/*=====================================================================
		Noteeraamattomat yritykset:
		---------------------------------------------------------------------*/
		if &jaktyypp = "M" and &suorlaji in (1, 4) then do;

			RAJA = &HenkYhtOsVapOsuus * &netvar;

			/*=====================================================================
			Alle X% matemaattisesta arvosta:
				- kaikki verovapaata
			---------------------------------------------------------------------*/
			if &osinkoe <= RAJA then do;
				EILIST_VAPM = &osinkoe;
			end;

			/*=====================================================================
			Yli X% matemaattisesta arvosta:
				- vapa (vapaata), eli alle jv osa
				- at eli ansiotulo-osuus Y%:a
			---------------------------------------------------------------------*/
			else if &osinkoe > RAJA then do;
				EILIST_VAPM = RAJA;
				EILIST_AT = sum(&osinkoe, -RAJA) * &HenkYhtOsAnsOsuus;
			end;		

			/*=====================================================================
			Kaikki asetetaan eilistattujen bruttoon
			---------------------------------------------------------------------*/
			EILIST_BR = &osinkoe;

		end;

		/*=====================================================================
		Julkisesti noteeratut yritykset:
			- X%:a pomatuloveron alaista, 1-X%a vapaata
		---------------------------------------------------------------------*/
		else if (&jaktyypp = "J" and &suorlaji in (1, 4)) 
			or (&jaktyypp = '' and &suorlaji in (1, 4))
			then do;
				LIST_BR = &osinkoe;
				LIST_POT = &JulkPOOsuus * &osinkoe;
				LIST_VAPAA = sum(LIST_BR, -LIST_POT);	
		end;

		/*=====================================================================
		Noteeraamattomat REIT-yritykset:
			- kokonaan veronalaista, mutta jaetaan kuin muutkin
			  noteeraamattomat yritykset
		---------------------------------------------------------------------*/
		else if &jaktyypp = "M" and &suorlaji = 3 then do;

			RAJA = &HenkYhtOsVapOsuus * &netvar;

			/*=====================================================================
			Alle X% matemaattisesta arvosta:
				- luetaan pomatuloksi
			---------------------------------------------------------------------*/
			if &osinkoe <= RAJA then do;
				EILISTREIT_POT = &osinkoe;
			end;

			/*=====================================================================
			Yli X% matemaattisesta arvosta:
				- vapa (vapaata), eli alle jv osa
				- at eli ansiotulo-osuus Y%:a
			---------------------------------------------------------------------*/
			else if &osinkoe > RAJA then do;
				EILISTREIT_POT = RAJA;
				EILISTREIT_AT = sum(&osinkoe, -RAJA);
			end;		

			/*=====================================================================
			Kaikki asetetaan eilistattujen REIT-yhtiiden bruttoon
			---------------------------------------------------------------------*/
			EILISTREIT_BR = &osinkoe;

		end;

		/*=====================================================================
		Julkisesti noteeratut REIT-yritykset:
			- Kokonaan pomatuloa
		---------------------------------------------------------------------*/

		else if &jaktyypp = "J" and &suorlaji = 3 then do;
			LISTREIT_POT = &osinkoe;
			LISTREIT_BR = &osinkoe;
		end;

		/*=============================================================================
		Noteeraamattomat osuuskunnat:
			- rajan ylittvlt osalta X%:a pomatuloveron alaista, 1-X%:a vapaata,
			  lasketaan henkiltasolla loppuun
		-----------------------------------------------------------------------------*/

		else if (&jaktyypp = "M" and &suorlaji in (2, 5, 6))
			or (&jaktyypp = '' and &suorlaji in (2, 5, 6))
			then do;
				EILISTOS_PBR = &osinkoe;
				EILISTOS_BR = &osinkoe;
		end;

		/*=============================================================================
		Noteeraamattomat alle 500 jsenen osuuskunnat:
		-----------------------------------------------------------------------------*/
		else if (&jaktyypp = "S" and &suorlaji in (2, 5, 6)) then do;

			RAJA = &HenkYhtOsVapOsuus * &netvar;

			/*=====================================================================
			Alle X% matemaattisesta arvosta (tai jos simuloidaan lainsdnt
			ennen vuotta 2015):
				- ksitelln kuin muitakin noteeraamattomia osuuskuntia
			---------------------------------------------------------------------*/
			if &osinkoe <= RAJA or &vuosi < 2015 then do;
				EILISTOS_PBR = &osinkoe;
			end;

			/*=====================================================================
			Yli X% matemaattisesta arvosta:
				- rajaan asti ksitelln kuin muitakin noteeraamattomia
				  osuuskuntia
				- rajan jlkeen Y%:a ansiotuloa
			---------------------------------------------------------------------*/	
			else do;
				EILISTOS_PBR = RAJA;
				EILISTOS_AT = sum(&osinkoe, -RAJA) * &HenkYhtOsAnsOsuus;
			end;
			
			/*=====================================================================
			Joka tapauksessa merkitn kaikki bruttoon
			---------------------------------------------------------------------*/	
			EILISTOS_BR = &osinkoe;

		end;

		/*==================================================================================================
		Julkisesti noteeratut osuuskunnat:
			- X%:a pomatuloveron alaista, 1-X%:a vapaata
		---------------------------------------------------------------------------------------------------*/

		else if (&jaktyypp = "J" and &suorlaji in (2, 5, 6))
			then do;
				LISTOS_BR = &osinkoe;
				LISTOS_POT = &JulkOSPOOsuus * &osinkoe;
				LISTOS_VAPAA = (1-&JulkOSPOOsuus) * &osinkoe;
		end;

%mend OsinkojenJakoErillis;

/* Makro henkiltason osinkotulojen jaottelulle
vuosi:				Lainsdntvuosi
EILIST_VAPM:		Listaamattomien yhtiiden osingot, alle X% matemaattisesta 
					nettovarallisuusarvosta
EILISTOS_PBR:		Se osa noteeraamattomien osuuskuntien ylijmst, josta
					ptelln pomatuloveron alainen osuus
HenkYhtVapRaja:		Listaamattomien yhtiden nettovarallisuusarvon alittavien 
					kevennetyn verotuksen osuus
HenkYhtPOOsuus1:	Noteeraamattomien yhtiiden tuottorajan ja osinkorajan alittava 
					pomatuloveronalainen osuus
HenkYhtPOOsuus2:	Noteeraamattomien yhtiiden tuottorajan alittava ja osinkorajan ylittv 
					pomatuloveronalainen osuus
OspKorVeroVap:		Osuuspoman korkojen verovapauden raja
OspKorkoPOOsuus:	Osuuspoman korkojen pomatulonveronalainen osuus
EiJulkOSPORaja:		Noteeraamattoman osuuskunnan ylijmn verotuksen euroraja ()
EiJulkOSPOOsuus1:	Noteeraamattoman osuuskunnan ylijmn eurorajan alittavasta osuudesta 
					pomatuloveron alaista
EiJulkOSPOOsuus2:	Noteeraamattoman osuuskunnan ylijmn eurorajan ylittvst osuudesta 
					pomatuloveron alaista
*/

%macro HenkiloJaottelu(vuosi, eilist_vapm, eilistos_pbr, 
			HenkYhtVapRaja, HenkYhtPOOsuus1, HenkYhtPOOsuus2, OspKorVeroVap, 
		    OspKorkoPOOsuus, EiJulkOSPORaja, EiJulkOSPOOsuus1, EiJulkOSPOOsuus2); 

		/*=====================================================================
		Noteerattomat yhtit:
		---------------------------------------------------------------------*/

		if &HenkYhtVapRaja GT 0 then do;

			/*=====================================================================
			Jos noteeraamattomien yhtiiden osinkojen vapaaprosentin alittavien
			yhteissumma ylitt kattorajan X euroa, tllin:
			- raja*ali% + yli%:a rajan ylittvist ovat veronalaista pomatuloa.
			---------------------------------------------------------------------*/

			if &eilist_vapm > &HenkYhtVapRaja then do;
				EILIST_POT = sum(&HenkYhtVapRaja * (&HenkYhtPOOsuus1), sum(&eilist_vapm, -&HenkYhtVapRaja) * (&HenkYhtPOOsuus2));
			end;

			/*=====================================================================
			Jos noteeraamattomien yhtiiden vapaaprosentin alittavien yhteissumma
			alittaa kattorajan X euroa.
			- raja*ali% on veronalaista pomatuloa.
			---------------------------------------------------------------------*/
			else if &eilist_vapm <= &HenkYhtVapRaja then do;
				EILIST_POT = &eilist_vapm * (&HenkYhtPOOsuus1);
			end;

		end;

		/*=====================================================================
		Osuuskunnat (ennen vuotta 2015):
		---------------------------------------------------------------------*/
		if &vuosi < 2015 then do;

			/*=====================================================================
			- kattorajan alittava osa osuuspoman koroista on verovapaata.
			- kattorajan ylittv osuus pomatulona verotettavaa.
			---------------------------------------------------------------------*/
			if &eilistos_pbr > &OspKorVeroVap then do;
				EILISTOS_POT = sum(&eilistos_pbr, -&OspKorVeroVap) * &OspKorkoPOOsuus;
			end;

		end;

		/*=============================================================================
		Noteerattomat osuuskunnat (vuodesta 2015 lhtien):
		-----------------------------------------------------------------------------*/
		else if &vuosi >= 2015 then do;

			/*=============================================================================
			Laskenta riippuu siit ylittk bruttomr rajan. Jos alittaa:
			- brutto*ali% on veronalaista pomatuloa.
			-----------------------------------------------------------------------------*/
			if &eilistos_pbr <= &EiJulkOSPORaja then do; 
				EILISTOS_POT = &EiJulkOSPOOsuus1 * &eilistos_pbr;
			end;

			/*=============================================================================
			Jos raja ylittyy:
			- raja*ali% + yli%:a rajan ylittvist ovat veronalaista pomatuloa
			-----------------------------------------------------------------------------*/
			else if &eilistos_pbr > &EiJulkOSPORaja then do;
				EILISTOS_POT = sum(&EiJulkOSPORaja * (&EiJulkOSPOOsuus1), sum(&eilistos_pbr, -&EiJulkOSPORaja) * (&EiJulkOSPOOsuus2));
			end;

		end;
	
%mend HenkiloJaottelu;


/*=============================================================================
Varsinainen simulointiohjelma:
1. Osinkosarjatason laskelmat
-----------------------------------------------------------------------------*/

* Lhttaulun nimi ;

%let osavuosi = %substr(&avuosi., 3, 2); 
%let osdata = r&osavuosi._osingot;

data startdat.start_osinko; set pohjadat.&osdata;

	/* Luodaan muuttujat tyhjin numeerisina */
	length RAJA EILIST_VAPM EILIST_AT EILIST_BR LIST_BR LIST_POT
		LIST_VAPAA EILISTREIT_BR EILISTREIT_AT EILISTREIT_POT
		LISTREIT_BR LISTREIT_POT LISTOS_BR LISTOS_POT LISTOS_VAPAA
		EILISTOS_AT EILISTOS_PBR EILISTOS_BR 8;

%OsinkojenJakoErillis(
		&LVUOSI, jaktyypp, suorlaji, dmat, osinkoe,
		&HenkYhtOsVapOsuus, &JulkPOOsuus, &HenkYhtOsAnsOsuus, &JulkOSPOOsuus);

	/*=========================================================================
	Korot ja osingot, brutto
	-------------------------------------------------------------------------*/
	OSINGOT_BR = osinkoe;

run;

/*=============================================================================
Varsinainen simulointiohjelma:
2. Summaus henkiltasolle
-----------------------------------------------------------------------------*/

proc sql;
create view temp.osingot_summa as select hnro,
	sum(OSINGOT_BR) as OSINGOT_BR,
	sum(EILIST_BR) as EILIST_BR,
	sum(EILIST_AT) as EILIST_AT,
	sum(EILIST_VAPM) as EILIST_VAPM,
	sum(LIST_BR) as LIST_BR,
	sum(LIST_POT) as LIST_POT,
	sum(LIST_VAPAA) as LIST_VAPAA,
	sum(EILISTREIT_BR) as EILISTREIT_BR,
	sum(EILISTREIT_AT) as EILISTREIT_AT,
	sum(EILISTREIT_POT) as EILISTREIT_POT,
	sum(LISTREIT_BR) as LISTREIT_BR,
	sum(LISTREIT_POT) as LISTREIT_POT,
	sum(EILISTOS_AT) as EILISTOS_AT,
	sum(EILISTOS_PBR) as EILISTOS_PBR,
	sum(EILISTOS_BR) as EILISTOS_BR,
	sum(LISTOS_BR) as LISTOS_BR,
	sum(LISTOS_POT) as LISTOS_POT,
	sum(LISTOS_VAPAA) as LISTOS_VAPAA
	
	from startdat.start_osinko
	group by hnro
	order by hnro;
quit;

/*=============================================================================
Varsinainen simulointiohjelma:
3. Henkiltason laskelma
-----------------------------------------------------------------------------*/

data temp.osingot_simuloitu;
	set temp.osingot_summa;

	%HenkiloJaottelu(&LVUOSI, EILIST_VAPM, EILISTOS_PBR, 
		&HenkYhtVapRaja, &HenkYhtPOOsuus1, &HenkYhtPOOsuus2, &OspKorVeroVap, 
		&OspKorkoPOOsuus, &EiJulkOSPORaja, &EiJulkOSPOOsuus1, &EiJulkOSPOOsuus2); 

	/*=====================================================================
	Lasketaan verovapaat osinkotulot ja verovapaat ylijmt
	noteeraamattomista sek kaikkien verovapaiden summat.
	---------------------------------------------------------------------*/
	EILIST_VAPAA = sum(EILIST_BR, -EILIST_POT, -EILIST_AT);
	EILISTOS_VAPAA = sum(EILISTOS_BR, -EILISTOS_POT, -EILISTOS_AT);

	OSIN_VAPAA = sum(LIST_VAPAA, EILIST_VAPAA);
	OSU_VAPAA= sum(LIST_VAPAA, EILIST_VAPAA, LISTOS_VAPAA, EILISTOS_VAPAA);

	drop EILIST_VAPM EILISTOS_PBR;

	/*=========================================================================
	Nimemiset
	-------------------------------------------------------------------------*/
	label 
	OSINGOT_BR = "Osingot ja osuuspoman ylijm yhtens, MALLI"

	EILIST_BR = "Osingot noteeraamattomista yhtiist, MALLI"
	EILIST_AT = "Osingot noteeraamattomista yhtiist, ansiotuloveron alainen, MALLI"
	EILIST_POT = "Osingot noteeraamattomista yhtiist, pomatuloveron alainen, MALLI"
	EILIST_VAPAA = "Osingot noteeraamattomista yhtiist, verovapaa osuus, MALLI"

	LIST_BR = "Osingot julkisesti noteeratuista yhtiist, MALLI"
	LIST_POT = "Osingot julkisesti noteeratuista yhtiist, pomatuloveron alainen, MALLI"
	LIST_VAPAA = "Osingot julkisesti noteeratuista yhtiist, verovapaa osuus, MALLI"

	EILISTREIT_BR = "Osingot noteeraamattomista REIT-yhtiist, MALLI"
	EILISTREIT_AT = "Osingot noteeraamattomista REIT-yhtiist, ansiotuloveron alainen, MALLI"
	EILISTREIT_POT = "Osingot noteeraamattomista REIT-yhtiist, pomatuloveron alainen, MALLI"

	LISTREIT_BR = "Osingot julkisesti noteeratuista REIT-yhtiist, MALLI"
	LISTREIT_POT = "Osingot julkisesti noteeratuista REIT-yhtiist, pomatuloveron alainen, MALLI"

	EILISTOS_BR = "Noteeraamattomien osuuskuntien ylijm, MALLI"
	EILISTOS_AT = "Noteeraamattomien osuuskuntien ylijm, ansiotuloveron alainen, MALLI"
	EILISTOS_POT = "Noteeraamattomien osuuskuntien ylijm, pomatuloveron alainen, MALLI"
	EILISTOS_VAPAA = "Noteeraamattomien osuuskuntien ylijm, verovapaa osuus, MALLI"

	LISTOS_BR = "Julkisesti noteerattujen osuuskuntien ylijm, MALLI"
	LISTOS_POT = "Julkisesti noteerattujen osuuskuntien ylijm, pomatuloveron alainen, MALLI"
	LISTOS_VAPAA = "Julkisesti noteerattujen osuuskuntien ylijm, verovapaa osuus, MALLI"

	OSIN_VAPAA = "Osingot, verovapaat yhteens, MALLI"
	OSU_VAPAA = "Osingot ja osuuspoman ylijm, verovapaat yhteens, MALLI";

run;

